@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '2.08_01'; # TRIAL VERSION
+our $VERSION = '2.08_02'; # TRIAL VERSION
 
 use parent 'Exporter';
 use Test::Builder;
@@ -76,7 +76,19 @@ my $test = Test::Builder->new;
 our $_IN_VERSION_ALL_OK = 0;
 our %FILE_FIND_RULE_EXTRAS = (
   untaint => 1,
-  ($^O eq 'MSWin32' ? (untaint_pattern => qr|^(([a-zA-Z]:)?[-+@\w./]+)$|x) : ()),
+  #
+  # the untainting pattern for Windows used by File::Find seems to be wrong.
+  #
+  #  - cwd returns an absolute directory will usually return a volume (e.g. 'C:')
+  #  - windows file systems frequently include directorieswith parans and spaces in them
+  #    I am a little dubious that accepting them is safe.  The alternative is that
+  #    this module would not be installable in a lot of environments, and I honestly
+  #    don't believe that many people are using Test::Version in taint mode on Windows
+  #    anyway, so I am weighing the risk as worth it.
+  #  - windows has short names with tildes in them (e.g. "FOO~1").  Tilde is not a
+  #    special character in windows shells anyway, so I think we should be safe there.
+  #
+  ($^O eq 'MSWin32' ? (untaint_pattern => qr|^(([a-zA-Z]:)?[-+@\w./\~\(\) ]+)$|x) : ()),
 );
 
 
@@ -267,7 +279,7 @@ Test::Version - Check to see that version's in modules are sane
 
 =head1 VERSION
 
-version 2.08_01
+version 2.08_02
 
 =head1 SYNOPSIS
 
